@@ -10,6 +10,7 @@
 #ifndef EDITORTAB_H
 #define EDITORTAB_H
 
+#include "resizewatcher.h"
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -142,6 +143,9 @@ public:
     QIcon m_defaultTabIcon;
     QIcon m_unsavedTabIcon;
 
+    SaveLayoutAfterResizeWatcher *m_resizeWatcher;
+    bool m_layoutRefreshScheduled = false;
+
 public Q_SLOTS:
     // for undo/redo, views
     void gotoEntry(DocPosition pos);
@@ -344,6 +348,7 @@ private:
     KReplace *m_replace{};
 
     // BEGIN views
+    GlossaryNS::GlossaryView *m_glossaryView;
     MergeView *m_syncView{};
     MergeView *m_syncViewSecondary{};
     CatalogView *m_transUnitsView{};
