@@ -180,21 +180,18 @@ public:
         GlossaryModelColumnCount,
     };
 
-    explicit GlossaryModel(QObject *parent /*, Glossary* glossary*/);
+    explicit GlossaryModel(QObject *parent);
     ~GlossaryModel() override = default;
 
-    // QModelIndex index (int row, int column, const QModelIndex & parent = QModelIndex() ) const;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &, int role = Qt::DisplayRole) const override;
     QVariant headerData(int section, Qt::Orientation, int role = Qt::DisplayRole) const override;
-    // Qt::ItemFlags flags(const QModelIndex&) const;
 
     bool canFetchMore(const QModelIndex &parent) const override;
     void fetchMore(const QModelIndex &parent) override;
 
     bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
-    // bool insertRows(int row,int count,const QModelIndex& parent=QModelIndex());
     QByteArray appendRow(const QString &_english, const QString &_target);
 
 public Q_SLOTS:
