@@ -57,11 +57,15 @@ ProjectTab::ProjectTab(QWidget *parent)
     m_filterEdit->setPlaceholderText(i18n("Quick search..."));
     m_filterEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L. Accepts regular expressions"));
     connect(m_filterEdit, &QLineEdit::textChanged, this, &ProjectTab::setFilterRegExp, Qt::QueuedConnection);
+    connect(m_filterEdit, &QLineEdit::returnPressed, this, [this] {
+        m_browser->setFocus();
+    });
     new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_L), this, SLOT(setFocus()), nullptr, Qt::WidgetWithChildrenShortcut);
 
     l->addWidget(m_filterEdit);
     l->addWidget(m_browser);
     m_browser->setAlternatingRowColors(true);
+    setFocusProxy(m_browser);
     connect(m_browser, &ProjectWidget::fileOpenRequested, this, &ProjectTab::fileOpenRequested);
     connect(Project::instance()->model(), &ProjectModel::totalsChanged, this, &ProjectTab::updateStatusBar);
     connect(Project::instance()->model(), &ProjectModel::loadingAboutToStart, this, &ProjectTab::initStatusBarProgress);
@@ -78,6 +82,10 @@ ProjectTab::ProjectTab(QWidget *parent)
     setXMLFile(QStringLiteral("projectmanagerui.rc"), true);
     setUpdatedXMLFile();
 
+    KConfig config;
+    KConfigGroup stateGroup(&config, QStringLiteral("State"));
+    const bool hideCompletedItems = (stateGroup.exists() && stateGroup.readEntry("HideCompletedItems", false));
+
 #define ADD_ACTION_SHORTCUT_ICON(_name, _text, _shortcut, _icon)                                                                                               \
     action = nav->addAction(QStringLiteral(_name));                                                                                                            \
     action->setText(_text);                                                                                                                                    \
@@ -147,6 +155,7 @@ ProjectTab::ProjectTab(QWidget *parent)
     action->setToolTip(i18nc("@action:inmenu", "Hide fully translated files and folders"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("hide_table_row")));
     action->setCheckable(true);
+    action->setChecked(hideCompletedItems);
     ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_T));
     connect(action, &QAction::triggered, this, &ProjectTab::toggleTranslatedFiles);
 
